==> nodejs_interop-0.5.0.tar.gz: lib/src/node/path.dart <==
/// Provides interoperability with [`path`](https://nodejs.org/api/path.html) module.
@JS()
library nodejs_interop.node.path;

import 'package:js/js.dart';

/// The [`path`](https://nodejs.org/api/path.html) module.
@JS()
abstract class PathModule {

  /// The path delimiter for the current platform.
  /// This is `";"` on Windows and `":"` on other platforms.
  external String get delimiter;

  /// Provides access to POSIX specific implementations of the methods.
  external PathModule get posix;

  /// The path separator for the current platform.
  /// This is `"\"` on Windows and `"/"` on other platforms.
  external String get sep;

  /// Provides access to Windows specific implementations of the methods.
  external PathModule get win32;

  /// Gets the part of [path] after the last separator, optionally removing the specified file [extension].
  external String basename(String path, [String extension]);

  /// Gets the part of [path] before the last separator.
  external String dirname(String path);

  /// Gets the file extension of [path]: the portion of [basename] from the last `.` to the end (including the `.` itself).
  /// If the file name starts with a `.`, then that is not considered the extension.
  external String extname(String path);

  /// Formats a path string from an object. This is the opposite of [parse].
  external String format(Path pathObject);

  /// Returns `true` if [path] is an absolute path and `false` if it is a relative path.
  external bool isAbsolute(String path);

  /// Joins the given path parts into a single path using the current platform's [sep].
  external String join([String part1, String part2, String part3, String part4, String part5, String part6, String part7, String part8]);

  /// Normalizes [path], simplifying it by handling `..`, and `.`, and removing redundant path separators whenever possible.
  external String normalize(String path);

  /// Returns an object whose properties represent significant elements of the [path].
  external Path parse(String path);

  /// Attempts to convert [path] to an equivalent relative path from [from] based on the current directory.
  external String relative(String from, String path);

  /// Canonicalizes a path.
  ///
  /// This is guaranteed to return the same path for two different input paths if and only if both input paths point to the same location.
  /// Unlike [normalize], it returns absolute paths when possible.
  external String resolve([String part1, String part2, String part3, String part4, String part5, String part6, String part7, String part8]);

  /// On Windows systems only, returns an equivalent [namespace-prefixed path](https://msdn.microsoft.com/library/windows/desktop/aa365247.aspx#namespaces)
  /// for the given [path]. On POSIX systems, the method is non-operational and always returns [path] without modifications.
  external String toNamespacedPath(String path);
}

/// An object whose properties represent significant elements of a path.
@JS()
@anonymous
class Path {

  /// Creates a new path object.
  external factory Path({String base, String dir, String ext, String name, String root});

  /// The file name.
  external String get base;
  external set base(String value);

  /// The directory name.
  external String get dir;
  external set dir(String value);

  /// The file extension.
  external String get ext;
  external set ext(String value);

  /// The file name without extension.
  external String get name;
  external set name(String value);

  /// The root component.
  external String get root;
  external set root(String value);
}

==> nodejs_interop-0.6.0.tar.gz: lib/src/node/path.dart <==
/// Provides interoperability with [`path`](https://nodejs.org/api/path.html) module.
@JS()
library nodejs_interop.node.path;

import 'package:js/js.dart';

/// The [`path`](https://nodejs.org/api/path.html) module.
@JS()
abstract class PathModule {

  /// The path delimiter for the current platform.
  /// This is `";"` on Windows and `":"` on other platforms.
  external String get delimiter;

  /// Provides access to POSIX specific implementations of the methods.
  external PathModule get posix;

  /// The path separator for the current platform.
  /// This is `"\"` on Windows and `"/"` on other platforms.
  external String get sep;

  /// Provides access to Windows specific implementations of the methods.
  external PathModule get win32;

  /// Gets the part of [path] after the last separator, optionally removing the specified file [extension].
  external String basename(String path, [String extension]);

  /// Gets the part of [path] before the last separator.
  external String dirname(String path);

  /// Gets the file extension of [path]: the portion of [basename] from the last `.` to the end (including the `.` itself).
  /// If the file name starts with a `.`, then that is not considered the extension.
  external String extname(String path);

  /// Formats a path string from an object. This is the opposite of [parse].
  external String format(PathObject pathObject);

  /// Returns `true` if [path] is an absolute path and `false` if it is a relative path.
  external bool isAbsolute(String path);

  /// Joins the given path parts into a single path using the current platform's [sep].
  external String join([String part1, String part2, String part3, String part4, String part5, String part6, String part7, String part8]);

  /// Normalizes [path], simplifying it by handling `..`, and `.`, and removing redundant path separators whenever possible.
  external String normalize(String path);

  /// Returns an object whose properties represent significant elements of the [path].
  external PathObject parse(String path);

  /// Attempts to convert [path] to an equivalent relative path from [from] based on the current directory.
  external String relative(String from, String path);

  /// Canonicalizes a path.
  ///
  /// This is guaranteed to return the same path for two different input paths if and only if both input paths point to the same location.
  /// Unlike [normalize], it returns absolute paths when possible.
  external String resolve([String part1, String part2, String part3, String part4, String part5, String part6, String part7, String part8]);

  /// On Windows systems only, returns an equivalent [namespace-prefixed path](https://msdn.microsoft.com/library/windows/desktop/aa365247.aspx#namespaces)
  /// for the given [path]. On POSIX systems, the method is non-operational and always returns [path] without modifications.
  external String toNamespacedPath(String path);
}

/// An object whose properties represent significant elements of a path.
@JS()
@anonymous
class PathObject {

  /// Creates a new path object.
  external factory PathObject({String base, String dir, String ext, String name, String root});

  /// The file name.
  external String get base;
  external set base(String value);

  /// The directory name.
  external String get dir;
  external set dir(String value);

  /// The file extension.
  external String get ext;
  external set ext(String value);

  /// The file name without extension.
  external String get name;
  external set name(String value);

  /// The root component.
  external String get root;
  external set root(String value);
}
